import { existsSync } from "node:fs";
import process from "node:process";
import { ResolverFactory } from "oxc-resolver";
import { dirname } from "pathe";

//#region src/index.ts
const RE_JS = /\.[cm]?js$/;
const RE_TS = /\.[cm]?ts$/;
function createResolver({ tsconfig, cwd = process.cwd() } = {}) {
	const resolver = new ResolverFactory({
		mainFields: [
			"types",
			"typings",
			"module",
			"main"
		],
		conditionNames: [
			"types",
			"typings",
			"import",
			"require"
		],
		extensions: [
			".d.ts",
			".d.mts",
			".d.cts",
			".ts",
			".mts",
			".cts"
		],
		modules: ["node_modules", "node_modules/@types"],
		tsconfig: tsconfig ? {
			configFile: tsconfig,
			references: "auto"
		} : void 0
	});
	return (id, importer) => {
		const directory = importer ? dirname(importer) : cwd;
		const resolution = resolver.sync(directory, id);
		if (!resolution.path) return null;
		const resolved = resolution.path;
		if (RE_JS.test(resolved)) {
			const dts = tryExists(resolved.replace(RE_JS, ".d.ts")) || tryExists(resolved.replace(RE_JS, ".d.mts")) || tryExists(resolved.replace(RE_JS, ".d.cts"));
			return ensureTs(dts);
		}
		return ensureTs(resolved);
	};
}
function ensureTs(path) {
	return path && RE_TS.test(path) ? path : null;
}
function tryExists(path) {
	return existsSync(path) ? path : null;
}

//#endregion
export { createResolver };