import {
  SearchBuilder
} from "./chunk-P7QOZBII.js";
import {
  Fields,
  RankingType
} from "./chunk-CDOBNSCL.js";

// src/ranking.ts
import { addDays, format } from "date-fns";
var dateFormat = "yyyyMMdd";
var RankingBuilder = class {
  /**
   * constructor
   * @private
   */
  constructor(params = {}, api) {
    this.params = params;
    this.api = api;
    this.date$ = addDays(Date.now(), -1);
    this.type$ = RankingType.Daily;
  }
  date(date) {
    this.date$ = date;
    return this;
  }
  type(type) {
    this.type$ = type;
    return this;
  }
  /**
   * gzip圧縮する。
   *
   * 転送量上限を減らすためにも推奨
   * @param {GzipLevel} level gzip圧縮レベル(1～5)
   * @return {RankingBuilder} this
   */
  gzip(level) {
    this.set({ gzip: level });
    return this;
  }
  /**
   * クエリパラメータをセットする
   * @private
   * @return {RankingBuilder} this
   */
  set(obj) {
    Object.assign(this.params, obj);
    return this;
  }
  /**
   * なろう小説APIへのリクエストを実行する
   * @returns ランキング
   */
  execute() {
    const date = format(this.date$, dateFormat);
    this.set({ rtype: `${date}-${this.type$}` });
    return this.api.executeRanking(this.params);
  }
  async executeWithFields(fields = [], opt) {
    const ranking = await this.execute();
    const fields$ = Array.isArray(fields) ? fields.length == 0 ? [] : [...fields, Fields.ncode] : [fields, Fields.ncode];
    const rankingNcodes = ranking.map(({ ncode }) => ncode);
    const builder = new SearchBuilder({}, this.api);
    builder.fields(fields$);
    if (opt) {
      builder.opt(opt);
    }
    builder.ncode(rankingNcodes);
    builder.limit(ranking.length);
    const result = await builder.execute();
    return ranking.map((r) => ({
      ...r,
      // eslint-disable-next-line @typescript-eslint/no-explicit-any
      ...result.values.find((novel) => novel.ncode == r.ncode)
    }));
  }
};

export {
  RankingBuilder
};
//# sourceMappingURL=chunk-4VC3246A.js.map