import {
  BooleanNumber,
  StopParam
} from "./chunk-CDOBNSCL.js";

// src/search-builder.ts
var SearchBuilderBase = class {
  /**
   * constructor
   * @private
   */
  constructor(params = {}, api) {
    this.params = params;
    this.api = api;
  }
  static distinct(array) {
    return Array.from(new Set(array));
  }
  static array2string(n) {
    if (Array.isArray(n)) {
      return this.distinct(n).join("-");
    } else {
      return n.toString();
    }
  }
  /**
   *
   * @return {SearchBuilder} this
   */
  limit(num) {
    this.set({ lim: num });
    return this;
  }
  /**
   *
   * @return {SearchBuilder} this
   */
  start(num) {
    this.set({ st: num });
    return this;
  }
  /**
   *
   * @return {SearchBuilder} this
   */
  page(no, count = 20) {
    return this.limit(count).start(no * count);
  }
  /**
   * 出力順序を指定する。指定しない場合は新着順となります。
   * old	古い順
   * @param {TOrder} order 出力順序
   * @return {SearchBuilder} this
   */
  order(order) {
    this.set({ order });
    return this;
  }
  /**
   * gzip圧縮する。
   *
   * 転送量上限を減らすためにも推奨
   * @param {GzipLevel} level gzip圧縮レベル(1～5)
   * @return {SearchBuilder} this
   */
  gzip(level) {
    this.set({ gzip: level });
    return this;
  }
  /**
   * クエリパラメータをセットする
   * @private
   * @return {SearchBuilder} this
   */
  set(obj) {
    this.params = { ...this.params, ...obj };
    return this;
  }
  /**
   * クエリパラメータを削除する
   */
  unset(key) {
    delete this.params[key];
    return this;
  }
};
var NovelSearchBuilderBase = class _NovelSearchBuilderBase extends SearchBuilderBase {
  /**
   * a
   * @return {SearchBuilder} this
   */
  word(word) {
    this.set({ word });
    return this;
  }
  /**
   *
   * @return {SearchBuilder} this
   */
  notWord(word) {
    this.set({ notword: word });
    return this;
  }
  /**
   *
   * @return {SearchBuilder} this
   */
  byTitle(bool = true) {
    this.set({ title: bool ? BooleanNumber.True : BooleanNumber.False });
    return this;
  }
  /**
   *
   * @return {SearchBuilder} this
   */
  byOutline(bool = true) {
    this.set({ ex: bool ? BooleanNumber.True : BooleanNumber.False });
    return this;
  }
  /**
   *
   * @return {SearchBuilder} this
   */
  byKeyword(bool = true) {
    this.set({ keyword: bool ? BooleanNumber.True : BooleanNumber.False });
    return this;
  }
  /**
   *
   * @return {SearchBuilder} this
   */
  byAuthor(bool = true) {
    this.set({ wname: bool ? BooleanNumber.True : BooleanNumber.False });
    return this;
  }
  /**
   *
   * @return {SearchBuilder} this
   */
  isBL(bool = true) {
    if (bool) {
      this.set({ isbl: BooleanNumber.True });
    } else {
      this.set({ notbl: BooleanNumber.True });
    }
    return this;
  }
  /**
   *
   * @return {SearchBuilder} this
   */
  isGL(bool = true) {
    if (bool) {
      this.set({ isgl: BooleanNumber.True });
    } else {
      this.set({ notgl: BooleanNumber.True });
    }
    return this;
  }
  /**
   *
   * @return {SearchBuilder} this
   */
  isZankoku(bool = true) {
    if (bool) {
      this.set({ iszankoku: BooleanNumber.True });
    } else {
      this.set({ notzankoku: BooleanNumber.True });
    }
    return this;
  }
  /**
   *
   * @return {SearchBuilder} this
   */
  isTensei(bool = true) {
    if (bool) {
      this.set({ istensei: BooleanNumber.True });
    } else {
      this.set({ nottensei: BooleanNumber.True });
    }
    return this;
  }
  /**
   *
   * @return {SearchBuilder} this
   */
  isTenni(bool = true) {
    if (bool) {
      this.set({ istenni: BooleanNumber.True });
    } else {
      this.set({ nottenni: BooleanNumber.True });
    }
    return this;
  }
  /**
   *
   * @return {SearchBuilder} this
   */
  isTT() {
    this.set({ istt: BooleanNumber.True });
    return this;
  }
  /**
   *
   * @return {SearchBuilder} this
   */
  length(length) {
    this.set({ length: _NovelSearchBuilderBase.array2string(length) });
    return this;
  }
  kaiwaritu(min, max) {
    let n;
    if (max != null) {
      n = `${min}-${max}`;
    } else {
      n = min;
    }
    this.set({ kaiwaritu: n });
    return this;
  }
  /**
   *
   * @return {SearchBuilder} this
   */
  sasie(num) {
    this.set({ sasie: _NovelSearchBuilderBase.array2string(num) });
    return this;
  }
  /**
   *
   * @return {SearchBuilder} this
   */
  time(num) {
    this.set({ time: _NovelSearchBuilderBase.array2string(num) });
    return this;
  }
  /**
   *
   * @return {SearchBuilder} this
   */
  ncode(ncodes) {
    this.set({ ncode: _NovelSearchBuilderBase.array2string(ncodes) });
    return this;
  }
  /**
   *
   * @return {SearchBuilder} this
   */
  type(type) {
    this.set({ type });
    return this;
  }
  /**
   *
   * @return {SearchBuilder} this
   */
  buntai(buntai) {
    this.set({ buntai: _NovelSearchBuilderBase.array2string(buntai) });
    return this;
  }
  /**
   *
   * @return {SearchBuilder} this
   */
  isStop(bool = true) {
    this.set({ stop: bool ? StopParam.Stopping : StopParam.NoStopping });
    return this;
  }
  /**
   *
   * @return {SearchBuilder} this
   */
  isPickup(bool = true) {
    this.set({ ispickup: bool ? BooleanNumber.True : BooleanNumber.False });
    return this;
  }
  lastUpdate(x, y) {
    let date;
    if (typeof x == "string") {
      date = x;
    } else if (x instanceof Date && y instanceof Date) {
      date = `${Math.floor(x.getTime() / 1e3)}-${Math.floor(
        y.getTime() / 1e3
      )}`;
    } else {
      date = `${x}-${y}`;
    }
    this.set({ lastup: date });
    return this;
  }
  lastNovelUpdate(x, y) {
    let date;
    if (typeof x == "string") {
      date = x;
    } else if (x instanceof Date && y instanceof Date) {
      date = `${Math.floor(x.getTime() / 1e3)}-${Math.floor(
        y.getTime() / 1e3
      )}`;
    } else {
      date = `${x}-${y}`;
    }
    this.set({ lastupdate: date });
    return this;
  }
  /**
   * なろう小説APIへの検索リクエストを実行する
   * @returns {Promise<NarouSearchResults>} 検索結果
   */
  execute() {
    return this.api.executeNovel(this.params);
  }
};
var SearchBuilder = class _SearchBuilder extends NovelSearchBuilderBase {
  /**
   *
   * @return {SearchBuilder} this
   */
  bigGenre(genre) {
    this.set({ biggenre: _SearchBuilder.array2string(genre) });
    return this;
  }
  /**
   *
   * @return {SearchBuilder} this
   */
  notBigGenre(genre) {
    this.set({ notbiggenre: _SearchBuilder.array2string(genre) });
    return this;
  }
  /**
   *
   * @return {SearchBuilder} this
   */
  genre(genre) {
    this.set({ genre: _SearchBuilder.array2string(genre) });
    return this;
  }
  /**
   *
   * @return {SearchBuilder} this
   */
  notGenre(genre) {
    this.set({ notgenre: _SearchBuilder.array2string(genre) });
    return this;
  }
  /**
   *
   * @return {SearchBuilder} this
   */
  userId(ids) {
    this.set({ userid: _SearchBuilder.array2string(ids) });
    return this;
  }
  /**
   *
   * @return {SearchBuilder} this
   */
  isR15(bool = true) {
    if (bool) {
      this.set({ isr15: 1 });
    } else {
      this.set({ notr15: 1 });
    }
    return this;
  }
  /**
   *
   * @return {SearchBuilder} this
   */
  fields(fields) {
    this.set({ of: _SearchBuilder.array2string(fields) });
    return this;
  }
  opt(option) {
    this.set({ opt: _SearchBuilder.array2string(option) });
    return this;
  }
};

export {
  SearchBuilderBase,
  NovelSearchBuilderBase,
  SearchBuilder
};
//# sourceMappingURL=chunk-P7QOZBII.js.map