import { N as NarouNovel, b as NarouRankingResult, R as RankingResult, D as DefaultSearchResultFields } from './narou-fH9osIoh.js';
import { b as RankingParams, R as RankingType, q as GzipLevel, F as Fields, u as SearchResultFields, O as OptionalFields } from './narou-search-results-D5yqPRZ7.js';
import './ranking-history.js';
import './util/type.js';

/**
 * ランキングヘルパー
 * @class Ranking
 */
declare class RankingBuilder {
    protected params: Partial<RankingParams>;
    protected api: NarouNovel;
    protected date$: Date;
    protected type$: RankingType;
    /**
     * constructor
     * @private
     */
    constructor(params: Partial<RankingParams> | undefined, api: NarouNovel);
    date(date: Date): this;
    type(type: RankingType): this;
    /**
     * gzip圧縮する。
     *
     * 転送量上限を減らすためにも推奨
     * @param {GzipLevel} level gzip圧縮レベル(1～5)
     * @return {RankingBuilder} this
     */
    gzip(level: GzipLevel): this;
    /**
     * クエリパラメータをセットする
     * @private
     * @return {RankingBuilder} this
     */
    protected set(obj: Partial<RankingParams>): this;
    /**
     * なろう小説APIへのリクエストを実行する
     * @returns ランキング
     */
    execute(): Promise<NarouRankingResult[]>;
    executeWithFields(): Promise<RankingResult<DefaultSearchResultFields>[]>;
    executeWithFields<TFields extends Fields>(fields: TFields | TFields[]): Promise<RankingResult<SearchResultFields<TFields>>[]>;
    executeWithFields(fields: never[], opt: OptionalFields | OptionalFields[]): Promise<RankingResult<DefaultSearchResultFields | "weekly_unique">[]>;
    executeWithFields<TFields extends Fields>(fields: TFields | TFields[], opt: OptionalFields | OptionalFields[]): Promise<RankingResult<SearchResultFields<TFields> | "weekly_unique">[]>;
}

export { RankingBuilder as default };
